lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Sun, 14 Jun 2009 18:57:48 +0200
From:	Evgeni Golov <sargentd@...-welt.net>
To:	linux-kernel@...r.kernel.org
Cc:	Evgeni Golov <sargentd@...-welt.net>
Subject: [PATCH 2/2] use the TASK_COMM_LEN macro instead of sizeof(tsk->comm)

sizeof(tsk->comm) == TASK_COMM_LEN, always, so why not use it?

Signed-off-by: Evgeni Golov <sargentd@...-welt.net>
---
 fs/exec.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/fs/exec.c b/fs/exec.c
index 6f1eeb8..14fd909 100644
--- a/fs/exec.c
+++ b/fs/exec.c
@@ -911,9 +911,9 @@ static void flush_old_files(struct files_struct * files)
 
 char *get_task_comm(char *buf, struct task_struct *tsk)
 {
 	/* buf must be at least sizeof(tsk->comm) in size */
 	task_lock(tsk);
-	strlcpy(buf, tsk->comm, sizeof(tsk->comm));
+	strlcpy(buf, tsk->comm, TASK_COMM_LEN);
 	task_unlock(tsk);
 	return buf;
 }
@@ -921,7 +921,7 @@ char *get_task_comm(char *buf, struct task_struct *tsk)
 void set_task_comm(struct task_struct *tsk, char *buf)
 {
 	task_lock(tsk);
-	strlcpy(tsk->comm, buf, sizeof(tsk->comm));
+	strlcpy(tsk->comm, buf, TASK_COMM_LEN);
 	task_unlock(tsk);
 	perf_counter_comm(tsk);
 }
@@ -930,7 +930,7 @@ int flush_old_exec(struct linux_binprm * bprm)
 {
 	char * name;
 	int i, ch, retval;
-	char tcomm[sizeof(current->comm)];
+	char tcomm[TASK_COMM_LEN];
 
 	/*
 	 * Make sure we have a private signal table and that
@@ -911,9 +911,9 @@ static void flush_old_files(struct files_struct * files)
 char *get_task_comm(char *buf, struct task_struct *tsk)
 {
-	/* buf must be at least sizeof(tsk->comm) in size */
+	/* buf must be at least sizeof(tsk->comm) (=TASK_COMM_LEN) in size */
 	task_lock(tsk);
-- 
1.6.3.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ